package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.loan.LoanApplication;

import java.util.List;


/**
 * 贷款申请主Mapper接口
 * 
 * @author boman
 * @date 2024-04-24
 */
public interface LoanApplicationMapper 
{
    /**
     * 查询贷款申请主
     * 
     * @param loanApplicationId 贷款申请主主键
     * @return 贷款申请主
     */
    public LoanApplication selectLoanApplicationByLoanApplicationId(Long loanApplicationId);

    /**
     * 查询贷款申请主列表
     * 
     * @param loanApplication 贷款申请主
     * @return 贷款申请主集合
     */
    public List<LoanApplication> selectLoanApplicationList(LoanApplication loanApplication);

    /**
     * 查询需要保后的数据
     *
     * @param loanApplication
     * @return
     */
    public List<LoanApplication> selectLoanAfterList(LoanApplication loanApplication);

    /**
     * 统计使用查询列表
     * @param loanApplication
     * @return
     */
    public List<LoanApplication> selectLoanApplicationListStatistics(LoanApplication loanApplication);

    /**
     * 新增贷款申请主
     * 
     * @param loanApplication 贷款申请主
     * @return 结果
     */
    public int insertLoanApplication(LoanApplication loanApplication);

    /**
     * 修改贷款申请主
     * 
     * @param loanApplication 贷款申请主
     * @return 结果
     */
    public int updateLoanApplication(LoanApplication loanApplication);

    /**
     * 删除贷款申请主
     * 
     * @param loanApplicationId 贷款申请主主键
     * @return 结果
     */
    public int deleteLoanApplicationByLoanApplicationId(Long loanApplicationId);

    /**
     * 批量删除贷款申请主
     * 
     * @param loanApplicationIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLoanApplicationByLoanApplicationIds(Long[] loanApplicationIds);

    List<LoanApplication> conferenceList(LoanApplication loanApplication);

    List<LoanApplication> conferenceProdList(LoanApplication loanApplication);

    void updateLoanApplication2(LoanApplication loanApplication);
}
